// $Id: J4CDCParameterList.cc,v 1.5 2003/02/28 14:01:11 hoshina Exp $
//*************************************************************************
//* --------------------
//* J4CDCParameterList
//* --------------------
//* (Description)
//* 	Class for describing his/her detector compornents.
//*
//* (Update Record)
//*	2002/10/06  K.Hoshina	Original version.
//*************************************************************************
// modified to Intermediate Tracker(IT), 2003/07/07 by Hyuncheong

#include "J4ITParameterList.hh"
 
//=====================================================================
//* constructor -------------------------------------------------------

J4ITParameterList::J4ITParameterList()
{
   SetMaterials();
   SetParameters();
   SetVisAttributes();
   SetColors();
}

//=====================================================================
//* destructor -------------------------------------------------------

J4ITParameterList::~J4ITParameterList()
{
   delete  fITColor;
   delete  fLayerColor;
   delete  fLayerPhiOffset;
}

//=====================================================================
//* SetMaterials ------------------------------------------------------
void J4ITParameterList::SetMaterials()
{
#if 1
   fITMaterial          = "Air";
   fLayerMaterial       = "CO2Isobutane";

#else
   fITMaterial          = "vacuum";
   fLayerMaterial       = "vacuum";
#endif

}

//=====================================================================
//* SetParameters -----------------------------------------------------
void J4ITParameterList::SetParameters()
{
   // IT
   fITInnerRadius      = 44.*cm;
   fITOuterRadius      = 157.*cm;
   fITHalfZLength      = 157.*cm;
   fITDeltaPhi         = 360.*deg;
   fITPhiOffset        = 360.*deg;

   // Layer
   fNlayers           = 10;
   fLayerThick        = 10; 
   fLayerDeltaPhi     = 10; 
   fLayerSpacingR     = 10; 
   fLayerZincrement   = 10;
   fFirstLayerR       = 10;
   fFirstLayerZ       = 10;
   fLayerPhiOffset    = new G4double[fNlayers];

   fLayerPhiOffset[0] =  0.   *rad; // axial
   fLayerPhiOffset[1] =  0.032*rad; // stereo
   fLayerPhiOffset[2] = -0.032*rad; // stereo 
   fLayerPhiOffset[3] =  0.   *rad; // axial 
   fLayerPhiOffset[4] =  0.032*rad; // stereo
   fLayerPhiOffset[5] = -0.032*rad; // stereo 
   fLayerPhiOffset[6] =  0.   *rad; // axial 
   fLayerPhiOffset[7] =  0.016*rad; // stereo 
   fLayerPhiOffset[8] = -0.016*rad; // stereo 
   fLayerPhiOffset[9] =  0.   *rad; // axial 
}

//=====================================================================
//* SetVisAttributes --------------------------------------------------
void J4ITParameterList::SetVisAttributes()
{
#if 0
   fITVisAtt         = TRUE;
   fLayerVisAtt       = FALSE;

#else
   fITVisAtt         = TRUE;
   fLayerVisAtt       = FALSE;
#endif

}

//=====================================================================
//* SetColors ---------------------------------------------------------
void J4ITParameterList::SetColors()
{
   fITColor          = new G4Color(0., 0., 1.);
   fLayerColor       = new G4Color(0., 1., 0.);
}

//=====================================================================
//* GetLayerNumber ----------------------------------------------------
/*
G4int J4CDCParameterList::GetLayerNumber(G4int superlayerid, 
                                         G4int myid) const
{
   if (fIsOddSuperLyrOutermost) {
      return superlayerid * 3 + myid;
   } else {
      if (superlayerid == 0) return 0;
      return (superlayerid - 1) * 3 + 1 + myid;
   }
}
*/
